@@ -1,6 +1,7 @@
 from loguru import logger
+from typing import Dict
 
-PDU = dict[str, str]
+PDU = Dict[str, str]
 
 
 def unpack(cmd: str) -> PDU:
